==> plugin-android-0.0.1-sources.jar: com/zoyi/channel/plugin/android/util/RequestUtils.java <==
package com.zoyi.channel.plugin.android.util;

import android.webkit.MimeTypeMap;
import com.zoyi.channel.plugin.android.util.io.FilenameUtils;
import com.zoyi.retrofit2.okhttp3.MediaType;
import com.zoyi.retrofit2.okhttp3.MultipartBody;
import com.zoyi.retrofit2.okhttp3.RequestBody;
import org.json.JSONObject;

import java.io.File;
import java.util.HashMap;
import java.util.Map;

import static com.zoyi.retrofit2.okhttp3.MediaType.parse;

/**
 * Created by mika on 8/9/16.
 */
public class RequestUtils {
  Map<String, Object> map;

  public static RequestUtils form() {
    RequestUtils requestUtils = new RequestUtils();
    requestUtils.map = new HashMap<>();

    return requestUtils;
  }

  public static RequestUtils form(Map<String, Object> map) {
    RequestUtils requestUtils = form();
    if (map != null) {
      for (Map.Entry<String, Object> kvp : map.entrySet()) {
        if (kvp.getKey() != null && kvp.getValue() != null) {
          requestUtils.set(kvp.getKey(), kvp.getValue());
        }
      }
    }
    return requestUtils;
  }

  public RequestUtils set(String key, Object value) {
    if (map == null) {
      throw new NullPointerException("You must call \'form\' first");
    }

    map.put(key, value);
    return this;
  }

  public RequestBody create() {
    if (map == null) {
      throw new NullPointerException("You must call \'form\' first");
    }

    return RequestBody.create(
        parse("application/json; charset=utf-8"),
        new JSONObject(map).toString());
  }

  public static MultipartBody.Part makeMultipart(String path) {
    MimeTypeMap mimeTypeMap = MimeTypeMap.getSingleton();
    String type = mimeTypeMap.getMimeTypeFromExtension(FilenameUtils.getExtension(path).toLowerCase());
    File file = new File(path);
    RequestBody requestFile = RequestBody.create(MediaType.parse("multipart/form-data"), file);
    return MultipartBody.Part.createFormData("file", file.getName(), requestFile);
  }
}

==> plugin-android-1.0.0-sources.jar: com/zoyi/channel/plugin/android/util/RequestUtils.java <==
package com.zoyi.channel.plugin.android.util;

import android.webkit.MimeTypeMap;
import com.zoyi.channel.plugin.android.util.io.FilenameUtils;
import com.zoyi.retrofit2.okhttp3.MediaType;
import com.zoyi.retrofit2.okhttp3.MultipartBody;
import com.zoyi.retrofit2.okhttp3.RequestBody;
import org.json.JSONObject;

import java.io.File;
import java.util.HashMap;
import java.util.Map;

import static com.zoyi.retrofit2.okhttp3.MediaType.parse;

/**
 * Created by mika on 8/9/16.
 */
public class RequestUtils {
  Map<String, Object> map;

  public static RequestUtils form() {
    RequestUtils requestUtils = new RequestUtils();
    requestUtils.map = new HashMap<>();

    return requestUtils;
  }

  public static RequestUtils form(Map<String, Object> map) {
    RequestUtils requestUtils = form();
    if (map != null) {
      for (Map.Entry<String, Object> kvp : map.entrySet()) {
        if (kvp.getKey() != null && kvp.getValue() != null) {
          requestUtils.set(kvp.getKey(), kvp.getValue());
        }
      }
    }
    return requestUtils;
  }

  public RequestUtils set(String key, Object value) {
    if (map == null) {
      throw new NullPointerException("You must call \'form\' first");
    }

    map.put(key, value);
    return this;
  }

  public RequestBody create() {
    if (map == null) {
      throw new NullPointerException("You must call \'form\' first");
    }

    return RequestBody.create(
        parse("application/json; charset=utf-8"),
        new JSONObject(map).toString());
  }

  public static MultipartBody.Part makeMultipart(String path) {
    MimeTypeMap mimeTypeMap = MimeTypeMap.getSingleton();
    String type = mimeTypeMap.getMimeTypeFromExtension(FilenameUtils.getExtension(path.toLowerCase()));

    if (type == null) {
      return null;
    }

    File file = new File(path);
    RequestBody requestFile = RequestBody.create(MediaType.parse("multipart/form-data"), file);
    return MultipartBody.Part.createFormData("file", file.getName(), requestFile);
  }
}
